@@ -1,14 +1,14 @@
 from typing import Optional
 
-from aiosmtplib.connection import DEFAULT_TIMEOUT
+from aiosmtplib.api import DEFAULT_TIMEOUT
 from jinja2 import Environment, FileSystemLoader
-from pydantic import BaseSettings as Settings
-from pydantic import DirectoryPath, EmailStr, conint
+from pydantic import DirectoryPath, EmailStr, SecretStr, conint
+from pydantic_settings import BaseSettings as Settings
 
 
 class ConnectionConfig(Settings):
     MAIL_USERNAME: str
-    MAIL_PASSWORD: str
+    MAIL_PASSWORD: SecretStr
     MAIL_PORT: int
     MAIL_SERVER: str
     MAIL_STARTTLS: bool
@@ -21,6 +21,8 @@ class ConnectionConfig(Settings):
     USE_CREDENTIALS: bool = True
     VALIDATE_CERTS: bool = True
     TIMEOUT: int = DEFAULT_TIMEOUT
+    LOCAL_HOSTNAME: Optional[str] = None
+    CERT_BUNDLE: Optional[str] = None
 
     def template_engine(self) -> Environment:
         """
@@ -29,7 +31,7 @@ class ConnectionConfig(Settings):
         folder = self.TEMPLATE_FOLDER
         if not folder:
             raise ValueError(
-                'Class initialization did not include a ``TEMPLATE_FOLDER`` ``PathLike`` object.'
+                "Class initialization did not include a ``TEMPLATE_FOLDER`` ``PathLike`` object."
             )
         template_env = Environment(loader=FileSystemLoader(folder))
         return template_env
